@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 import os.path
 
@@ -13,7 +12,7 @@ class Pinyin(object):
         In [1]: from xpinyin import Pinyin
         In [2]: p = Pinyin()
         In [3]: p.get_pinyin(u"上海")
-        Out[3]: 'shanghai'
+        Out[3]: 'shang-hai'
         In [4]: p.get_initials(u"上")
         Out[4]: 'S'
     请输入utf8编码汉字
@@ -23,21 +22,28 @@ class Pinyin(object):
     data_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                              'Mandarin.dat')
 
-    def __init__(self):
+    def __init__(self, data_path=data_path):
         self.dict = {}
-        for line in open(self.data_path):
+        for line in open(data_path):
             k, v = line.split('\t')
             self.dict[k] = v
 
-    def get_pinyin(self, chars=u'你好', splitter=''):
+    def get_pinyin(self, chars=u'你好', splitter=u'-'):
         result = []
+        flag = 1
         for char in chars:
             key = "%X" % ord(char)
             try:
                 result.append(self.dict[key].split(" ")[0].strip()[:-1]
                               .lower())
+                flag = 1
             except KeyError:
-                result.append(char)
+                if flag:
+                    result.append(char)
+                else:
+                    result[-1] += char
+                flag = 0
+
         return splitter.join(result)
 
     def get_initials(self, char=u'你'):
